.. only:: html

    ============
    Bibliography
    ============

    McArthur Forest Fire Danger System References
    ---------------------------------------------

    See: :ref:`ffdi-footnotes`

    Canadian Forest Fire Weather Index System References
    ----------------------------------------------------

    See: :ref:`fwi-footnotes`

    SDBA References
    ---------------

    See: :ref:`sdba-footnotes`

    General References
    ------------------

.. bibliography::
